/**
 * $RCSfile: DefaultMessageEventRequestListener.java,v $
 * $Revision: 1.3 $
 * $Date: 2008/12/02 20:24:10 $
 *
 * Copyright 2003-2007 Jive Software.
 *
 * All rights reserved. Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jivesoftware.smackx;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jivesoftware.smack.XMPPException;

/**
 *
 * Default implementation of the MessageEventRequestListener interface.<p>
 *
 * This class automatically sends a delivered notification to the sender of the message 
 * if the sender has requested to be notified when the message is delivered. 
 *
 * @author Gaston Dombiak
 */
public class DefaultMessageEventRequestListener implements MessageEventRequestListener {
    private static final Log LOG = LogFactory.getLog(DefaultMessageEventRequestListener.class);

    public void deliveredNotificationRequested(String from, String packetID,
                MessageEventManager messageEventManager)
    {
        // Send to the message's sender that the message has been delivered
        try {
            messageEventManager.sendDeliveredNotification(from, packetID);
        } catch (XMPPException e) {
            LOG.debug(e.getMessage(), e);
        }
    }

    public void displayedNotificationRequested(String from, String packetID,
            MessageEventManager messageEventManager)
    {
    }

    public void composingNotificationRequested(String from, String packetID,
            MessageEventManager messageEventManager)
    {
    }

    public void offlineNotificationRequested(String from, String packetID,
            MessageEventManager messageEventManager)
    {
    }
}
