package org.jivesoftware.smackx.packet;

import java.net.URI;

/**
 * packet to reprsent User Tune extension (http://xmpp.org/extensions/xep-0118.html).
 *
 * <iq type='set'
 *  from='stpeter@jabber.org/14793c64-0f94-11dc-9430-000bcd821bfb'
 *   id='tunes123'>
 *   <pubsub xmlns='http://jabber.org/protocol/pubsub'>
 *       <publish node='http://jabber.org/protocol/tune'>
 *           <item>
 *               <tune xmlns='http://jabber.org/protocol/tune'>
 *                 <artist>The Buddies</artist>
 *                 <length>500</length>
 *                 <rating>7</rating>
 *                 <source>creative commons.org</source>
 *                 <title>Monkey on a skateboard</title>
 *                 <track>5</track>
 *                 <uri>http://www.foo.com/monkey.html</uri>
 *               </tune>
 *           </item>
 *       </publish>
 *   </pubsub>
 * </iq>
 */
public class Tune extends PEPItem {
    private String artist;
    private short length;
    private int rating;
    private String source;
    private String title;
    private String track;
    private URI uri;

    public Tune(String id) {
        super(id);
    }

    String getNode() {
        return "http://jabber.org/protocol/tune";
    }

    String getItemDetailsXML() {
        StringBuilder buf = new StringBuilder();
        buf.append("<").append("tune").append(" xmlns=\"").append("http://jabber.org/protocol/tune").append("\">");
        if(artist != null) {
            buf.append("<artist>").append(artist).append("</artist>");
        }
        if(length != 0) {
            buf.append("<length>").append(length).append("</length>");
        }
        if(rating != 0) {
            buf.append("<rating>").append(rating).append("</rating>");
        }
        if(source != null) {
            buf.append("<source>").append(source).append("</source>");
        }
        if(title != null) {
            buf.append("<title>").append(title).append("</title>");
        }
        if(track != null) {
            buf.append("<track>").append(track).append("</track>");
        }
        if(uri != null) {
            buf.append("<uri>").append(uri).append("</uri>");
        }
        buf.append("</tune>");
        return buf.toString();
    }

    public String getArtist() {
        return artist;
    }

    public void setArtist(String artist) {
        this.artist = artist;
    }

    public short getLength() {
        return length;
    }

    public void setLength(short length) {
        if(length < 0) {
            length = (short)(length * -1);
        }
        this.length = length;
    }

    public int getRating() {
        return rating;
    }

    public void setRating(int rating) {
        if(rating < 0) {
            rating = 0;
        } else if(rating > 10) {
            rating = 10;
        }
        this.rating = rating;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getTrack() {
        return track;
    }

    public void setTrack(String track) {
        this.track = track;
    }

    public URI getUri() {
        return uri;
    }

    public void setUri(URI uri) {
        this.uri = uri;
    }
}
